import { existsSync, promises } from 'node:fs';
import { dirname, relative } from 'node:path';
import { execa } from './index3.mjs';
import { d as defineCommand, c as consola, e as box, a as colors } from '../shared/nuxi.bd0a2fa0.mjs';
import 'node:util';
import 'node:process';
import 'node:tty';
import { l as loadKit } from '../shared/nuxi.f56b6a0d.mjs';
import { s as sharedArgs, a as envNameArgs, l as legacyRootDirArgs, r as resolve } from '../shared/nuxi.cc8b5ffe.mjs';
import { s as setupDotenv } from '../shared/nuxi.c6d79f8e.mjs';
import 'node:url';
import 'node:child_process';
import 'node:string_decoder';
import '../shared/nuxi.d62f547c.mjs';
import '../shared/nuxi.2155838d.mjs';
import 'child_process';
import 'path';
import 'fs';
import 'node:timers/promises';
import 'node:os';
import 'node:events';
import 'node:v8';
import 'node:stream';
import 'node:buffer';
import 'node:stream/promises';
import 'node:perf_hooks';
import '../shared/nuxi.eaa29140.mjs';
import './satisfies.mjs';
import '../shared/nuxi.00903207.mjs';
import '../shared/nuxi.8054e4da.mjs';
import 'node:module';
import '../shared/nuxi.deb0a220.mjs';
import 'node:assert';
import 'crypto';
import 'module';
import 'perf_hooks';
import 'os';
import 'vm';
import 'url';
import 'assert';
import 'process';
import 'v8';
import 'util';
import 'tty';
import 'node:fs/promises';
import 'node:crypto';
import '../shared/nuxi.15c58622.mjs';
import '../shared/nuxi.c6313488.mjs';
import '../shared/nuxi.96236dcf.mjs';
import 'node:vm';

const preview = defineCommand({
  meta: {
    name: "preview",
    description: "Launches Nitro server for local testing after `nuxi build`."
  },
  args: {
    ...sharedArgs,
    ...envNameArgs,
    ...legacyRootDirArgs,
    dotenv: {
      type: "string",
      description: "Path to .env file"
    }
  },
  async run(ctx) {
    process.env.NODE_ENV = process.env.NODE_ENV || "production";
    const cwd = resolve(ctx.args.cwd || ctx.args.rootDir || ".");
    const { loadNuxtConfig } = await loadKit(cwd);
    const config = await loadNuxtConfig({
      cwd,
      envName: ctx.args.envName,
      // c12 will fall back to NODE_ENV
      overrides: (
        /* ctx.options?.overrides || */
        {}
      )
    });
    const resolvedOutputDir = resolve(
      config.srcDir || cwd,
      config.nitro.output?.dir || ".output",
      "nitro.json"
    );
    const defaultOutput = resolve(cwd, ".output", "nitro.json");
    const nitroJSONPaths = [resolvedOutputDir, defaultOutput];
    const nitroJSONPath = nitroJSONPaths.find((p) => existsSync(p));
    if (!nitroJSONPath) {
      consola.error(
        "Cannot find `nitro.json`. Did you run `nuxi build` first? Search path:\n",
        nitroJSONPaths
      );
      process.exit(1);
    }
    const outputPath = dirname(nitroJSONPath);
    const nitroJSON = JSON.parse(await promises.readFile(nitroJSONPath, "utf-8"));
    if (!nitroJSON.commands.preview) {
      consola.error("Preview is not supported for this build.");
      process.exit(1);
    }
    const info = [
      ["Node.js:", `v${process.versions.node}`],
      ["Nitro Preset:", nitroJSON.preset],
      ["Working directory:", relative(process.cwd(), outputPath)]
    ];
    const _infoKeyLen = Math.max(...info.map(([label]) => label.length));
    consola.log(
      box(
        [
          "You are running Nuxt production build in preview mode.",
          `For production deployments, please directly use ${colors.cyan(
            nitroJSON.commands.preview
          )} command.`,
          "",
          ...info.map(
            ([label, value]) => `${label.padEnd(_infoKeyLen, " ")} ${colors.cyan(value)}`
          )
        ].join("\n"),
        {
          title: colors.yellow("Preview Mode"),
          style: {
            borderColor: "yellow"
          }
        }
      )
    );
    const envExists = ctx.args.dotenv ? existsSync(resolve(cwd, ctx.args.dotenv)) : existsSync(cwd);
    if (envExists) {
      consola.info(
        `Loading \`${ctx.args.dotenv || ".env"}\`. This will not be loaded when running the server in production.`
      );
      await setupDotenv({ cwd, fileName: ctx.args.dotenv });
    }
    consola.info(`Starting preview command: \`${nitroJSON.commands.preview}\``);
    const [command, ...commandArgs] = nitroJSON.commands.preview.split(" ");
    consola.log("");
    await execa(command, commandArgs, { stdio: "inherit", cwd: outputPath });
  }
});

export { preview as default };
